<?php
/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
/**
 * The Paloose Plugin Options Panel Class.
 */
 
if ( !class_exists( 'PaloosePluginAdmin' ) ) {

   class PaloosePluginAdmin
   {
   
      /** The name of the Paloose options */
     var $palooseAdminOptionsName = "PaloosePluginAdminOptions";

     //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
     //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
     /**
      * The constructor for the Paloose admin class.
      */
    
      public function PaloosePluginAdmin()
      {
      } // PaloosePluginAdmin constructor

      //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
      //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
      /**
       * Sets up the scripts and styles for the admin page.
       */
    
      public function addScriptsStyles()
      {
 	      $plugindir = site_url() . "/wp-content/plugins/paloose-xml-processor";
	      wp_enqueue_script( 'loadjs', $plugindir . '/paloose-scripts/palooseAdmin.js');
	      echo "<link rel='stylesheet' href='$plugindir/paloose-styles/palooseAdmin.css' type='text/css' />\n";
	   }

      //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
      //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
      /**
       * Returns an array of Paloose options.
       *
       * Note that not all of these options will be presented in the admin panel.
       *
       * @return $palooseAdminOptions array of Paloose options
       */

      public function getAdminOptions()
      {
        // Set up the default settings if this is the first time through. Note that not all of these are available
         // to be changed on the admin page.
         $palooseOptions = array(
            'PALOOSE_DIRECTORY' => '../paloose-system', 
            'SITE_ROOT_DIRECTORY' => 'Your document root directory',
            'LOGGER_CONFIG' => '../chandos/configs/Paloose.xml', 
            'LOG4PHP_DIR' => '../log4php', 
            'TIME_ZONE' => 'Europe/London',
            // Where the paloose caches are held. Does not include the images cache for the directory. 
            'CACHE_DIR' => '/tmp',
            // Normally should not have to change this. The directory is always the top level user directory.
            'ROOT_SITEMAP' => 'sitemap.xmap',
            // Do we need sessions or is Paloose a client. If sessions are being controlled
            // somewhere else (WordPress etc) then we need to turn them off. WordPress
            // would also require Paloose acting as client.
            'SESSIONS_REQUIRED' => 'no',
            'CLIENT' => 'yes',
            // The error page to give back for User errors (errors in sitemap etc). They
            // are not run time errors (missing page (404) ). If you override these to your
            // area make sure that you use an absolute directory path - you can use the
            // 'context' pseudo-protocol here.
            'USER_EXCEPTION_PAGE' => 'resource://resources/errorHandling/userError.html',
            'USER_EXCEPTION_TRANSFORM' => 'resource://resources/transforms/errorPage2html.xsl',
            // Be careful of the path here - although it is relative it looks as an absolute one. It is in
            // fact relative to the Apache root document directory. Must always have a leading path
            // separator.
            'USER_EXCEPTION_STYLE' => '/paloose/resources/styles/userError.css',
            // The file that contains the gallery information in each gallery directory
            'GALLERY_INDEX' => 'gallery.xml',
            // Define if PATH on server is not set to pick up correct ImageMagick binaries
            'IMAGEMAGICK_BIN' => '/usr/local/bin/',
            // The error page to give back for internal programming errors. These should
            // not need to be overridden.
            'INTERNAL_EXCEPTION_PAGE' => 'resource://resources/errorHandling/internalError.html',
            'INTERNAL_EXCEPTION_TRANSFORM' => 'resource://resources/transforms/errorPage2html.xsl',
            // Be careful of the path here - although it is relative it looks as an absolute one. It is in
            // fact relative to the Apache root document directory. Must always have a leading path
            // separator.
            'INTERNAL_EXCEPTION_STYLE' => '/paloose/resources/styles/internalError.css',
            // Change this with caution - should not be changed in 99.9% of cases
            'SITEMAP_NAMESPACE' => 'http://apache.org/cocoon/sitemap/1.0',
            'SOURCE_NAMESPACE' => 'http://apache.org/cocoon/source/1.0',
            'DIR_NAMESPACE' => 'http://apache.org/cocoon/directory/2.0',
            'SQL_QUERY_NAMESPACE' => 'http://apache.org/cocoon/SQL/2.0',
            // Change this with caution - should only be changed for different translation
            // mechanism. Requires understanding of Paloose internals :-)
            'I18N_NAMESPACE' => 'http://apache.org/cocoon/i18n/2.1',
            'PAGE_HIT_TRANSFORM' => 'resource://resources/transforms/PageHit.xsl',
            'PALOOSE_NAMESPACE' => 'http://www.paloose.org/schemas/Paloose/1.0',
            );
            
         // Get the admin options from the database
         $existingPalooseOptions = get_option( $this->palooseAdminOptionsName );
         // If this is not the first time through then we read what has been already set
         if ( !empty( $existingPalooseOptions ) ) {
            // Scan through list of options and set the options array
            foreach ( $existingPalooseOptions as $key => $option ) {
               $palooseOptions[ $key ] = $option;
            } // foreach
         } // fi
         // At this point $palooseAdminOptions should have a list of the Paloose options so
         // update them within WordPress using the name decalred at the beginning of the class.
         update_option( $this->palooseAdminOptionsName, $palooseOptions );
         // Return them as well
         return $palooseOptions;
      } // getAdminOptions

      //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
      //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
      /**
       * Displays the Paloose options page.
       */
       
      public function printAdminPage()
      {
         // Get the currently set options
         $palooseOptions = $this->getAdminOptions();
         
         // Has there been a request for the form ?
         if ( isset( $_POST[ 'update_paloosePluginSettings' ] ) ) { 
            // Yes so update options
            if ( isset( $_POST[ 'palooseDirectory' ] ) ) {
               $palooseOptions[ 'PALOOSE_DIRECTORY' ] = apply_filters( 'content_save_pre', $_POST[ 'palooseDirectory' ] );
            } // fi
            if ( isset( $_POST[ 'siteRootDirectory' ] ) ) {
               $palooseOptions[ 'SITE_ROOT_DIRECTORY' ] = apply_filters( 'content_save_pre', $_POST[ 'siteRootDirectory' ] );
            } // fi
            if ( isset( $_POST[ 'loggerConfig' ] ) ) {
               $palooseOptions[ 'LOGGER_CONFIG' ] = apply_filters( 'content_save_pre', $_POST[ 'loggerConfig' ] );
            } // fi
            if ( isset( $_POST[ 'log4phpDir' ] ) ) {
               $palooseOptions[ 'LOG4PHP_DIR' ] = apply_filters( 'content_save_pre', $_POST[ 'log4phpDir' ] );
            } // fi
            if ( isset( $_POST[ 'timeZone' ] ) ) {
               $palooseOptions[ 'TIME_ZONE' ] = apply_filters( 'content_save_pre', $_POST[ 'timeZone' ] );
            } // fi
            if ( isset( $_POST[ 'cacheDir' ] ) ) {
               $palooseOptions[ 'CACHE_DIR' ] = apply_filters( 'content_save_pre', $_POST[ 'cacheDir' ] );
            } // fi
            if ( isset( $_POST[ 'rootSiteMap' ] ) ) {
               $palooseOptions[ 'ROOT_SITEMAP' ] = apply_filters( 'content_save_pre', $_POST[ 'rootSiteMap' ] );
            } // fi
            if ( isset( $_POST[ 'userExceptionPage' ] ) ) {
               $palooseOptions[ 'USER_EXCEPTION_PAGE' ] = apply_filters( 'content_save_pre', $_POST[ 'userExceptionPage' ] );
            } // fi
            if ( isset( $_POST[ 'userExceptionTransform' ] ) ) {
               $palooseOptions[ 'USER_EXCEPTION_TRANSFORM' ] = apply_filters( 'content_save_pre', $_POST[ 'userExceptionTransform' ] );
            } // fi
            if ( isset( $_POST[ 'userExceptionStyle' ] ) ) {
               $palooseOptions[ 'USER_EXCEPTION_STYLE' ] = apply_filters( 'content_save_pre', $_POST[ 'userExceptionStyle' ] );
            } // fi
            if ( isset( $_POST[ 'internalExceptionPage' ] ) ) {
               $palooseOptions[ 'INTERNAL_EXCEPTION_PAGE' ] = apply_filters( 'content_save_pre', $_POST[ 'internalExceptionPage' ] );
            } // fi
            if ( isset( $_POST[ 'internalExceptionTransform' ] ) ) {
               $palooseOptions[ 'INTERNAL_EXCEPTION_TRANSFORM' ] = apply_filters( 'content_save_pre', $_POST[ 'internalExceptionTransform' ] );
            } // fi
            if ( isset( $_POST[ 'internalExceptionStyle' ] ) ) {
               $palooseOptions[ 'INTERNAL_EXCEPTION_STYLE' ] = apply_filters( 'content_save_pre', $_POST[ 'internalExceptionStyle' ] );
            } // fi
            update_option( $this->palooseAdminOptionsName, $palooseOptions );
            // Output a confirming message if we have used the form
?>
      <div class="updated">
         <p><strong><?php _e( "Settings Updated.", "PaloosePlugin" ); ?></strong></p>
      </div>
<?php
      } // fi
    
    // Now print the form

?>
<div class="wrap">
   <h2>Paloose Plugin</h2>
   <div class="container">
      <ul class="tabs">
        <li><a href="#tab1">Options</a></li>
        <li><a href="#tab2">FAQs</a></li>
        <li><a href="#tab3">Usage Manual</a></li>
        <li><a href="#tab4">About</a></li>
        <li><a href="#tab5">Versions</a></li>
      </ul>

      <div class="tab_container">
         <div id="tab1" class="tab_content">
            <p>Warning!! Most of these values should not need to be changed.</p>
            <form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
               <table width="90%" cellspacing="13">
                <tr valign="top">
                   <td width="70%"><b>Directory where the paloose subsystem is stored</b><br/>
                   This is a relative path from the <code>paloose-includes</code> directory. If you wish to use the compact version of 
                   Paloose then this should be "<code>../paloose-compact-system</code>". Paloose does not have to be stored in the
                   plugin directory if you are using it elsewhere as a server on your system.</td>
                   <td><input type="text" size="60" name="palooseDirectory" value="<?php print( $palooseOptions['PALOOSE_DIRECTORY'] ); ?>">
                   </td>
                </tr>
                <tr valign="top">
                   <td><b>Directory where the XML documents are held that Paloose uses.</b><br/>
                   Can be a reletive path from the WordPress directory, or an absolute path.</td>
                   <td><input type="text" size="60" name="siteRootDirectory" value="<?php print( $palooseOptions['SITE_ROOT_DIRECTORY'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>Where the Logger configuration information is stored.</b></td>
                   <td><input type="text" size="60" name="loggerConfig" value="<?php print( $palooseOptions['LOGGER_CONFIG'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>Where the log4php code is stored.</b></td>
                   <td><input type="text" size="60" name="log4phpDir" value="<?php print( $palooseOptions['LOG4PHP_DIR'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>Current default time zone.</b></td>
                   <td><input type="text" size="60" name="timeZone" value="<?php print( $palooseOptions['TIME_ZONE'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>Where the Paloose caches are held.</b><br/>
                   Only used when caching is turned on in Paloose - not necessary when used as a plugin.</td>
                   <td><input type="text" size="60" name="cacheDir" value="<?php print( $palooseOptions['CACHE_DIR'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>Name of the root sitemap.</b><br/>
                   Normally should not have to change this. The directory is always the top level user directory.</td>
                   <td><input type="text" size="60" name="rootSiteMap" value="<?php print( $palooseOptions['ROOT_SITEMAP'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>The error page to give back for User errors (specifically from Paloose).</b><br/>
                   They are not run time errors (missing page (404) ). If you override these to your
                   area make sure that you use an absolute directory path, however, you can use the 'context' pseudo-protocol here.
                   See the Paloose documentation for more details of pseudo protocols.</td>
                   <td><input type="text" size="60" name="userExceptionPage" value="<?php print( $palooseOptions['USER_EXCEPTION_PAGE'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>The error page transform to convert to HTML.</b></td>
                   <td><input type="text" size="60" name="userExceptionTransform" value="<?php print( $palooseOptions['USER_EXCEPTION_TRANSFORM'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>The error page style.</b><br/>
                   Be careful of the path here - although it is relative it looks as an absolute one. It is in
                   fact relative to the Apache root document directory. Must always have a leading path
                   separator.</td>
                   <td><input type="text" size="60" name="userExceptionStyle" value="<?php print( $palooseOptions['USER_EXCEPTION_STYLE'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>The error page to give back for internal programming errors.</b><br/>
                    These should not need to be overridden.</td>
                   <td><input type="text" size="60" name="internalExceptionPage" value="<?php print( $palooseOptions['INTERNAL_EXCEPTION_PAGE'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>The internal error page transform to convert to HTML.</b></td>
                   <td><input type="text" size="60" name="internalExceptionTransform" value="<?php print( $palooseOptions['INTERNAL_EXCEPTION_TRANSFORM'] ); ?>">
                      </td>
                </tr>
                <tr valign="top">
                   <td><b>The internal error page transform to convert to HTML.</b><br/>
                   Be careful of the path here &#x2014; although it is relative it looks as an absolute one. It is in
                   fact relative to the Apache root document directory. Must always have a leading path
                   separator.</td>
                   <td><input type="text" size="60" name="internalExceptionStyle" value="<?php print( $palooseOptions['INTERNAL_EXCEPTION_STYLE'] ); ?>">
                      </td>
                </tr>
               </table>
               <div class="submit">
                  <input type="submit" name="update_paloosePluginSettings" value="<?php _e( 'Update Settings', 'PaloosePlugin' ) ?>" />
               </div>
            </form>
         </div> <!-- tab1 -->
         
         <div id="tab2" class="tab_content">
            <h2>Frequently Asked Questions</h2>
            
            <p>More FAQs can be found on the <a href="http://www.paloose.org/">main Paloose site</a>.

      <h3>What facilities do you intend to add to Paloose?</h3>
         <p>This is quite a difficult question as I have limited time and am not trying to do a complete Cocoon
            implementation in PHP5 &#x2014; a pointless exercise anyway. 
            The basic kernel of Paloose (common to both the server and plugin client) is
            unlikely to change other than a gradual refining of the code and improving the documentation.
            I am happy to look at anything that users suggest &#x2014;
            just EMAIL me at <a href="mailto:hsfr@hsfr.org.uk">hsfr@hsfr.org.uk</a>.
            I may add a further wrapper for other Content Management Systems such as Joomla!.</p>

      <h3>Can I use the Paloose logo on my site?</h3>
         <p>Yes please. I suggest the following <a href="http://www.paloose.org/pp/documentation/poweredByPaloose.png">"Powered by Paloose"
               logo</a> or the <a href="http://www.paloose.org/pp/documentation/poweredByPaloose-small.png">poweredByPaloose-small.png</a>.
            Scale it as you feel fit.</p>

      <h3>What systems will it run on?</h3>
         <p>Basically any system that will run PHP5. Currently the list is Mac OS-X, Linux, and other similar Unix systems. I also know of
            a system based on Apache 2.0/PHP5 on Windows Server 2003.</p>

      <h3>How can I improve the performance of Paloose?</h3>
         <p>Assuming that you are already using the caching system and want more speed, it is possible, but at the expense of a little
            effort (and possible obscurity), to tailor the Paloose code and your own sitemaps and XSL. The implications and method are
            described <a href="http://www.paloose.org/documentation/performance-1.html">here</a> in
            more detail.</p>

         <h3>What about caching in Paloose?</h3>
         <p>I have done considerable work on various ways of caching within Paloose and versions after 1.3.0 use pipeline data caching on
            certain generators and transformers. I confess that I am in a quandry over this as the gains from using a cache seem to be
            minimal and not really worth the effort except in some key cases &#x2014;
            see <a href="http://www.paloose.org/documentation/caching.html">my caching discussion</a> for more on this. It is not the end of the story, but more
            performance increases will probably come from elsewhere.</p>

         <h3>Help! Why am I getting "Class 'XsltProcessor' not found" errors</h3>
         <p>99% of the time this shows that you are running PHP5 without the XML/XSL support that there should be. Try recompiling PHP5
            with the following configuration parameters included </p>
         <pre>--with-xml --with-libxml-dir=&lt;dir path&gt; --with-xsl
         </pre>

         <h3>Help! Why am I getting "Parse error: syntax error, unexpected '=', expecting '(' in
            /../../paloose/lib/Paloose.php on line xx" errors</h3>
         <p>This means you are still running PHP4. You need to run PHP5. Speak to your ISP to provide PHP5. The other reason may be that
            your <code>.htaccess</code> file has not been set properly to use PHP5.</p>

         <h3>Help! Why am I getting "Input file not found" as the only browser output?</h3>
         <p>See <a href="htaccessProblem">FAQ entry</a> about the <code>.htaccess</code> file, this is the usual problem. Also
         make sure that you do not overwrite a system
               <code>.htaccess</code> that is required. That is why it is best to have your site
            in a separate folder.</p>

         <h3>Why do you not use schemas for the sitemaps?</h3>
         <p>This is a fairly contentious subject. Sitemaps are built in such expandable form that producing a schema in something like
               <a href="http://www.relaxng.org/">RELAX NG</a> or
               <a href="http://www.w3.org/XML/Schema">XML-Schema</a> is very difficult &#x2014; they
            simply do not have a rich enough structure to do what I think is necessary without having to use Schematron additions. The
            closest that I got to producing one used <link:link target="DSD-2" type="uri" ref="http://www.brics.dk/DSD/">DSD-2</link:link>.
            I wrote an extensible set of schemas which worked fine, but are now sadly out of date. I also produced schemas for Dublin Core,
            Jakarta Ant and RDF (although RDF is a major problem because it is impossible to write a universal validating XML schema for it
            &#x2014; it ain't the right sort of grammar and the current 2004 specification for RDF is flawed), all of which can be found on
            the <a href="http://www.brics.dk/DSD/">DSD-2</a> home page. DSD-2 is the best schema
            language we never had, sad ....</p>
      </t:group>

      <h3>Technical Trivia</h3>
         <p>The code that builds Paloose is a little rough and ready in places. It was my first PHP program (other than the odd embedded
            line within HTML) and it shows. I am more used to program in strongly typed languages having had a lifetime using Algol, Coral,
            Algol68, Pascal, Java at al; as well as more obscure offerings such as OmniMark, ELLA, Abel. I have programmed in Perl for
            many years and so PHP was not a wholly new experience. I am sure that I have used 10 lines in places where PHP5 would let me use
            one; never mind &#x2014; it suffices, the future will refine the code. </p>

         </div>
         <div id="tab3" class="tab_content">
            <p>Usage</p>
            
            <p>In order to use the Paloose plugin a thorough understanding of XML, XSL is required, as well as a good understanding of the Paloose
            server. Please read the <a href="http://www.paloose.org" target="Paloose">Paloose documentation on the Paloose site</a>.</p> 
            
            <p>Assuming that the plugin has been configured properly to find the Paloose system and the XML data file, then the
            plugin is called in the following manner with a page template:
            
            <pre>   &lt;?php
   /*
   Template Name: People
   */
   ?>
   
   &lt;?php get_header(); ?>
   &lt;div id="content" class="widecolumn">
   &lt;div id="main">
      &lt;?php echo paloose( [requested page], [query string] ); ?>
   &lt;/div>
   &lt;?php get_footer(); ?></pre>
   
   <p>For example the request <code>people.html?who=Mozart&amp;dates=yes</code> would be requested as

             <pre>   &lt;?php echo paloose-xml-processor( 'people.html', 'who=Mozart&amp;dates=yes' ); ?></pre>

<p>which could be match by a sitemap entry such as:</p>

<pre>   &lt;map:pipeline>
   
      &lt;map:match pattern="people.html">
         &lt;map:generate type="gedcom" src="context://content/data/composers.ged"/>
         &lt;map:transform src="context://resources/transforms/person2xhtml.xsl">
            &lt;map:parameter name="who" value="{request-param:who}"/>
            &lt;map:parameter name="dates" value="{request-param:dates}"/>
         &lt;/map:transform>
         &lt;map:serialize type="xml"/>
      &lt;/map:match>

   &lt;/map:pipeline>
</pre>
         </div>
         <div id="tab4" class="tab_content">
            <h4>About the Paloose Server and the Paloose Client WordPress Plugin</h4>

            <p>Paloose is a simplified version of Cocoon using PHP. It resulted from scratching a long standing personal itch:
            that there are very few ISPs who will support Java/Tomcat for web sites, other than as a very expensive "professional"
            addition. Almost all will support PHP5 (sorry, Paloose does not use PHP4), so I decided to write my version of a 
            simple, cut-down Cocoon in PHP5. I wanted to use XML on my personal sites but could not use Cocoon because of the 
            expense. After using Paloose for some time now, and finding it a good substitute for Cocoon in all 
            but the most complex sites, I have produced this plugin version for WordPress so that Web designers can benefit from the
            XML environment that pipelined system such as Cocoon and Paloose provide. Using it as a plugin to WordPress gives all the advantages that 
            both systems have: the flexibility and applicability of WordPress, together with the rich data structuring that XML can provide, with its
            ability to manipulate XML into various forms.</p>
        </div>
        
        <div id="tab5" class="tab_content">

         <h4>1.0.1b6</h4>
            <p>Paloose system (1.5.0b3) update to remove spurious logging output in SourceWritingTransformer</p>

         <h4>1.0.1b5</h4>
            <p>Cured bug in Paloose system (1.5.0b2) that stopped request parameters being recognised</p>

         <h4>1.0.1b4</h4>
            <p>Naming problem with plugin from earlier local version</p>

         <h4>1.0.1b3</h4>
            <p>More minor admin changes</p>

         <h4>1.0.1b2</h4>
            <p>Minor admin changes</p>

         <h4>1.0.1b1</h4>
            <p>Changed the calling function to support new Version 1.5.0 of Paloose First release. Note that Earlier versions of
             the plugin (1.0.0) will only work with Version 1.4.x of Paloose. This change was required to allow Paloose to work 
             with multi-calls on a single page with Joomla!</p>

            <h4>1.0.0</h4>
            <p>First release.</p>
        </div>
        
    </div>
</div>


</div>
       
<?php
      } // printAdminPage 

   } // PaloosePluginAdmin class

} // fi


?>