<?php
 
 
require_once( PALOOSE_LIB_DIRECTORY . "/authentication/AuthenticationHandler.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/authentication/AuthenticationHandlers.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/InternalException.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/UserException.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/RunException.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/ExitException.php" );
 
class AuthenticationManager {
   private $gDefault;
   
   
   private $gHandlers;
   
   
   private $sessionOrCookies; 
   const USE_COOKIES = 0;
   const USE_SESSIONS = 1;
   
   private $gUserName; 
   
   private $gPassword; 
      
   
   
   public function __construct()
   {
      $this->gHandlers = NULL;
      $this->gUserName = "";
      $this->gPassword = "";
      $this->sessionOrCookies = self::USE_COOKIES;
   }
   
   
   
   public function parse( DOMNode $inNode )
   {
      
      $pipelinesDom = new DOMDocument;
      $pipelinesDom->appendChild( $pipelinesDom->importNode( $inNode, 1 ) );
      $xPath = new domxpath( $pipelinesDom );
      $xPath->registerNamespace( "m", Environment::$configuration[ 'sitemapNamespace' ] );
      $nodeList = $xPath->query( "//*" );
      $idx = 0;
      foreach ( $nodeList as $node ) {
         if ( $node->localName == "handlers" ) {
            try {
               $this->gHandlers = new AuthenticationHandlers();
               $this->gHandlers->parse( $node );
            } catch ( UserException $e ) {
               throw new UserException( $e->getMessage(), $e->getCode(), $e->getDOMScrap() );
            }
         }
      }
   }
   
   
   
   public function authenticateUser( AuthenticationHandler $inHandler )
   {
      
      $authenticationURI = $inHandler->getAuthenticationURI();
      $authenticator = $inHandler->getAuthenticator();
      $redirectURI = $inHandler->getRedirectToURI();
      
      $uri = StringResolver::removePseudoProtocols( $redirectURI );
      
      $urlComponents = parse_url( $redirectURI );
      if ( $urlComponents === false ) {
         throw new UserException( "Malformed URI in redirect", PalooseException::SITEMAP_AUTHORISE_MANAGER_PARSE_ERROR );
      } else if ( array_key_exists( "scheme", $urlComponents ) and $urlComponents[ 'scheme' ] == "http" ) {
         
         throw new UserException( "External URI in redirect", PalooseException::SITEMAP_AUTHORISE_MANAGER_PARSE_ERROR );
      }
      
       $uriSource = Environment::getSource( $redirectURI );
      
      if ( $uriSource == Environment::UNKNOWN_SOURCE ) $uriSource = Environment::SUBMIT_ROOT ;
       switch ( $uriSource ) {
         case Environment::SUBMIT_ROOT :
            $expandedString = StringResolver::removePseudoProtocols( $redirectURI );
            
            $outputStream = new OutputStream( OutputStream::STANDARD_OUTPUT );
            
            $sitemap = Environment::$sitemapStack->root();
            $oldOutputStream = $sitemap->getOutputStream();
            $sitemap->setOutputStream( $outputStream );
            
            $sitemap->run( $expandedString, "", true ); 
            $sitemap->setOutputStream( $oldOutputStream );
            break;
               
         case Environment::SUBMIT_CURRENT :
            $expandedString = StringResolver::removePseudoProtocols( $redirectURI );
            
            $outputStream = new OutputStream( OutputStream::STANDARD_OUTPUT );
            
            $sitemap = Environment::$sitemapStack->peek();
            $oldOutputStream = $sitemap->getOutputStream();
            $sitemap->setOutputStream( $outputStream );
            
            $sitemap->run( $expandedString, "", true ); 
            $sitemap->setOutputStream( $oldOutputStream );
            break;
         default :
            throw new RunException( "Illegal return code '$uriSource' for string expansion source processing '$redirectURI'", PalooseException::UNKNOWN_STRING_EXPANSION_TYPE );
      }
      
      if ( strlen( $authenticationURI ) > 0 ) {
         
      } else if ( strlen( $authenticator ) > 0 ) {
      }
      $redirectURI = $inHandler->getRedirectToURI();
      return false;
   }
   
   
   
   public function isUserAuthorised()
   {
      $user = Environment::$sessionHandler->getVar( '__username' );
      if ( strlen( $user ) == 0 ) {
         return false;
      }
      return true;
   }
   
   
   
   public function checkAuthorization( AuthenticationHandler $inHandler, $inUser, $inPassword )
   {
      
      $authenticationURI = $inHandler->getAuthenticationURI();
      $authenticator = $inHandler->getAuthenticator();
      $requestParameterModule = Environment::$modules[ 'request-param' ];
      $requestParameterModule->add( "username", $inUser );
      $requestParameterModule->add( "password", $inPassword );
      
      if ( strlen( $authenticationURI ) > 0 ) {
         
         $uriSource = Environment::getSource( $authenticationURI );
         
         if ( $uriSource == Environment::UNKNOWN_SOURCE ) $uriSource = Environment::SUBMIT_ROOT ;
          switch ( $uriSource ) {
         
            case Environment::SUBMIT_ROOT :
               $expandedString = StringResolver::removePseudoProtocols( $authenticationURI );
               
               $outputStream = new OutputStream( OutputStream::BUFFER );
               
               $sitemap = Environment::$sitemapStack->root();
               $oldOutputStream = $sitemap->getOutputStream();
               $sitemap->setOutputStream( $outputStream );
               
               $sitemap->run( $expandedString, "", true ); 
               $sitemap->setOutputStream( $oldOutputStream );
               break;
                  
            case Environment::SUBMIT_CURRENT :
               $expandedString = StringResolver::removePseudoProtocols( $authenticationURI );
               
               $outputStream = new OutputStream( OutputStream::BUFFER );
               
               $sitemap = Environment::$sitemapStack->peek();
               $oldOutputStream = $sitemap->getOutputStream();
               $sitemap->setOutputStream( $outputStream );
               
               $sitemap->run( $expandedString, "", true ); 
               $sitemap->setOutputStream( $oldOutputStream );
               break;
         
            default :
               throw new RunException( "Illegal return code '$uriSource' for string expansion source processing '$authenticationURI'", PalooseException::UNKNOWN_STRING_EXPANSION_TYPE );
         
         }  
         
         
         
         $authenticationDOM = new DOMDocument();
         $authenticationDOM->loadXML( $outputStream->getBuffer() );
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         $xpath = new domxpath( $authenticationDOM );
         $ID = Utilities::getXPathListStringItem( 0, $xpath, "//ID" );
         if ( strlen( $ID ) > 0 ) {
            return $authenticationDOM;
         } else {
            return NULL;
         }
         
     } else if ( strlen( $authenticator ) > 0 ) {
     } else {
         throw new UserException( "No authorisation method specified for handler: " . $inHandler->getName(), PalooseException::SITEMAP_AUTHORISE_MANAGER_PARSE_ERROR, NULL );
     }
  
   }
   
   
   
   public function getHandlers()
   {
      return $this->gHandlers;
   } 
   
   
   
   public function toString()
   {
      $mess = "  <authentication-manager>\n";
      $mess .= $this->gHandlers->toString();
      $mess .= "  </authentication-manager>\n";
      return $mess;
   }
}
?>
