<?php
require_once( PALOOSE_LIB_DIRECTORY . "/environment/Utilities.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/environment/Environment.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/i18n/Catalogue.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/environment/StringResolver.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/InternalException.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/UserException.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/RunException.php" );
 
class Catalogues {
    
   private $gUntranslatedText;
    
   private $gCatalogueList;
    
   private $gDefaultCatalogue;
    
   
   
   
   public function __construct( DOMNode $inNode )
   {
      
      $cataloguesDOM = new DOMDocument;
      $cataloguesDOM->appendChild( $cataloguesDOM->importNode( $inNode, 1 ) );
      
      $cataloguesNode = $cataloguesDOM->getElementsByTagName( "catalogues" );
      $this->gDefaultCatalogue = $cataloguesNode->item( 0 )->getAttribute( "default" );
      if ( strlen ( $this->gDefaultCatalogue ) == 0 ) {
         throw new UserException( "Must have an associated default attribute with catalogues", PalooseException::SITEMAP_I18N_PARSE_ERROR, $cataloguesDOM );
      }
      
      $xpath = new domxpath( $cataloguesDOM );
      $xpath->registerNamespace( "m", Environment::$configuration[ 'sitemapNamespace' ] );
      $catalogueNodeList = $xpath->query( "//m:catalogue" );
      
      $defaultIdPresent = false;
      $this->gCatalogueList = array();
      try {
         foreach ( $catalogueNodeList as $node ) {
            $catalogue = new Catalogue( $node );
            $id = $catalogue->getId();
            $this->gCatalogueList[ $id ] = $catalogue;
            if ( $this->gDefaultCatalogue == $catalogue->getId() ) $defaultIdPresent = true;
          }
      } catch ( UserException $e ) {
         throw new UserException( $e->getMessage(), $e->getCode(), $e->getDOMScrap() );
      }
      
      if ( $defaultIdPresent === false ) {
         throw new UserException( "Default id '{$this->gDefaultCatalogue}' not found in catalogue list", PalooseException::SITEMAP_I18N_PARSE_ERROR, $cataloguesDOM );
      } else {
      }
      
   }
   
   
   public function getDefaultCatalogue()
   {
      return $this->gDefaultCatalogue;
   }
   
   
   public function getCatalogue( $inName )
   {
      if ( isset( $this->gCatalogueList[ $inName ] ) ) {
         return $this->gCatalogueList[ $inName ];
      } else {
         throw new RunException( "Cannot find translation catalogue series id: '$inName'", PalooseException::I18N_CATALOGUE_NOT_FOUND_TYPE );
      }
   }
   
   
   public function toString()
   {
      $mess = "     <catalogues default='{$this->gDefaultCatalogue}'>\n";
      foreach ( $this->gCatalogueList as $catalogueItem ) {
         $mess .= $catalogueItem->toString(); 
      }
      $mess .= "     </catalogues>\n";
      return $mess;
   }
 }
?>
