<?php
require_once( PALOOSE_LIB_DIRECTORY . "/environment/Utilities.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/pipelines/PipeElement.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/pipelines/PipeElementInterface.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/serialization/OutputStream.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/serialization/SerializerPipeElement.php" );
 
class HTMLSerializer extends SerializerPipeElement implements PipeElementInterface
{
      
   
   
   
    
   public function __construct( DOMDocument $inDOM, $inType = "", $inSrc = "", $inComponent = NULL )
   {
      try {
         parent::__construct( $inDOM, $inType, $inSrc, $inComponent );
      } catch ( UserException $e ) {
         throw new UserException( $e->getMessage(), $e->getCode(), $e->getDOMScrap() );
      }
   }
   
   
   
   public function run( VariableStack $inVariableStack, $inURL, $inQueryString, DOMDocument $inDOM )
   {
      if ( strlen( $this->gComponent->gPublicDoctype ) > 0 ) {
         $doctype = DOMImplementation::createDocumentType(
            "html",
            $this->gComponent->gPublicDoctype,
            $this->gComponent->gSystemDoctype );
         $dom = DOMImplementation::createDocument( null, 'html', $doctype );
      } else {
         $dom = new DOMDocument();
         $html = $dom->createElement( "html" );
         $dom->appendChild( $html );
      }
      $root = $dom->getElementsByTagName( "html" )->item( 0 );
      $dom->formatOutput = true;
      
      $head = $dom->createElement( "head" );
      $root->appendChild( $head );
      
      
      if ( strlen( $this->gComponent->gEncoding ) > 0 ) {
         $meta = $dom->createElement( "meta" );
         $meta->setAttribute( "http-equiv", "Content-Type" );
         $meta->setAttribute( "content", "text/html; charset=" . $this->gComponent->gEncoding );
         $head->appendChild( $meta );
      }
      
      $meta = $dom->createElement( "meta" );
      $meta->setAttribute( "name", "Generator" );
      $meta->setAttribute( "content", "Paloose Version " . Environment::$configuration[ 'palooseVersion' ] );
      $head->appendChild( $meta );
      
      $xPath = new domxpath( $inDOM );
      $docHeadList = $xPath->query( "/*[local-name() = 'html']/*[local-name() = 'head']" );
      if ( $docHeadList->length > 0 ) {
         
         foreach ( $docHeadList as $headNode ) {
            $newNode = $dom->importNode( $headNode, true );
            $head->appendChild( $newNode );
         }
      }
      
      
      
      $xPath = new domxpath( $inDOM );
      $docBody = $xPath->query( "/*[local-name() = 'html']/*[local-name() = 'body']" );
      
      if ( $docBody->length > 0 ) {
         
         $body = $dom->createElement( "body" );
         $root->appendChild( $head );
         $bodyNode = $docBody->item( 0 );
         $newNode = $dom->importNode( $bodyNode, true );
         $root->appendChild( $newNode );
      } else {
         
      }
      
      
      $root->removeAttribute( "__status" );
      $root->removeAttribute( "__file" );
      
      
      $outputString = $dom->saveXML();
      if ( $this->gComponent->gEncoding != "UTF-8" ) {
         $normalisedOutput = Utilities::utf8ToUnicodeEntities( $outputString );
      }
      
      if ( Environment::$gCookiesActive ) {
         Environment::$modules[ 'cookies' ]->outputCookies();
      }
      
      Environment::$sitemapStack->peek()->getOutputStream()->out( $outputString );
      Environment::$sitemapStack->peek()->getOutputStream()->clearBuffer();
      return NULL;
   }
   
   
   
   public function toString()
   {
      return parent::toString( $this->gGenericType );
   }
}
 
class _HTMLSerializer extends Serializer {
    
   
   
   
   public function __construct( $inName, $inSrc, DOMNode $inParameterNode, $inIsCachable )
   {
      parent::__construct( $inName, $inSrc, $inParameterNode, $inIsCachable );
      $this->gPackageName = "HTMLSerializer";
   }
}
?>
