<?php
 
require_once( PALOOSE_LIB_DIRECTORY . "/environment/Utilities.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/environment/Environment.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/transforming/Transformer.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/environment/StringResolver.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/InternalException.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/exception-handling/UserException.php" );
class Transformers {
   private $gDefault;
   
   
   private $gTransformers;
   
   private $gDOM;
      
   
   
   
    
   public function __construct()
   {
      $this->gTransformers = array();
   }
   
   
   
   public function parse( DOMNode $inNode )
   {
      
      $this->gDOM = new DOMDocument;
      $this->gDOM->appendChild( $this->gDOM->importNode( $inNode, 1 ) );
   
      
      $xpath = new domxpath( $this->gDOM );
      $xpath->registerNamespace( "m", Environment::$configuration[ 'sitemapNamespace' ] );
      $component = $xpath->query( "//m:transformer" );
      
      foreach ( $component as $node ) { 
         $name = $node->getAttribute( "name" );
         $src = $node->getAttribute( "src" );
         $isCachable = Utilities::normalizeBoolean( $node->getAttribute( "cachable" ) );
         if ( !strlen( $name ) or !strlen( $src ) ) {
            throw new UserException(
               "Sitemap component transformer must have name and src attributes defined",
               PalooseException::SITEMAP_TRANSFORMER_PARSE_ERROR,
               $this->gDOM );
         }
         
         if ( strstr( $src, Environment::getPathSeparator() ) == 1 ) {
            $packageFilename = $src;
         } else if ( !strstr( $src, ":" . Environment::getPathSeparator() ) ) {
            
            $packageFilename = PALOOSE_LIB_DIRECTORY . Environment::getPathSeparator() . $src;
         } else {
            
            $packageFilename = StringResolver::expandPseudoProtocols( $src );
         }
         
         
         
         $package = Utilities::stripFileName( $packageFilename );
         
         $path = Utilities::stripPath( StringResolver::expandPseudoProtocols( $packageFilename ) );
         
         
         if ( array_key_exists( $name, $this->gTransformers ) ) {
         } else {
         }
         
         require_once( $path . $package. ".php" );
         $transformerName = "_" . $package;
         $transformer = new $transformerName( $name, $path.$package, $node, $isCachable );
         
         try {
            $transformer->isValid();
            $this->gTransformers[ $name ] = $transformer;
         } catch( UserException $e ) {
            throw new UserException( $e->getMessage(), $e->getCode(), $this->gDOM );
         }
      }
   }
   
   
   
   public function setDefault( $inDefault )
   {
      if ( !( array_key_exists( $inDefault, $this->gTransformers ) ) ) {
           throw new UserException(
              "Default transformer '". $inDefault . "' not found",
              PalooseException::SITEMAP_TRANSFORMER_PARSE_ERROR,
              $this->gDOM );
      }
      $this->gDefault = $inDefault;
      return true;
   }
   
   
    
   public function getDefault()
   {
      return $this->gDefault;
   }
   
   
   
   public function getTransformer( $inType )
   {
      if ( !( array_key_exists( $inType, $this->gTransformers ) ) ) {
           throw new UserException( "Transformer '". $inType . "' not found", PalooseException::SITEMAP_TRANSFORMER_PARSE_ERROR );
      } else {
         return $this->gTransformers[ $inType ];
      }
   }
   
   
   
   public function getTransformerClassName( $inType )
   {
      if ( !( array_key_exists( $inType, $this->gTransformers ) ) ) {
           throw new UserException( "Transformer '". $inType . "' not found", PalooseException::SITEMAP_TRANSFORMER_PARSE_ERROR );
      } else {
         return $this->gTransformers[ $inType ]->getPackageName();
      }
   }
   
   
   
   public function toString()
   {
      $mess = "  <transformers default='{$this->gDefault}'>\n";
      foreach ( $this->gTransformers as $node ) {
         $mess .= $node->toString();
      }
      $mess .= "  </transformers>\n";
      return $mess;
   }
}
?>
