<?php
/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
/**
 * The main entry into the Paloose subsystem
 *
 * @package paloose
 * @subpackage PaloosePlugin
 *
 * @param string $inPage The page required (the URI data). Does not include host information etc
 * @param string $inQueryString the query string associated with the URI (optional) 
 * @return string the XHTML/XML data to return to the calling system
 */
 
function paloose( $inPage, $inQueryString ) {
  
   global $gPaloosePluginAdmin;
  
   // Get the currently set options
   $palooseOptions = $gPaloosePluginAdmin->getAdminOptions();
   
   // Now set all the Paloose constants. These are all gathered from the options page where they
   // are declared. Any not declared there will be set eventually to the defaults by the Paloose system.
   define( 'PALOOSE_DIRECTORY', dirname( __FILE__ ) . "/" . $palooseOptions[ 'PALOOSE_DIRECTORY' ] );
   define( 'PALOOSE_LIB_DIRECTORY', PALOOSE_DIRECTORY . '/lib' );
   define( 'PALOOSE_SITE_ROOT_DIRECTORY', $palooseOptions[ 'SITE_ROOT_DIRECTORY' ]  );
   define( 'PALOOSE_LOGGER_CONFIGURATION_FILE', $palooseOptions[ 'LOGGER_CONFIG' ] );
   define( 'PALOOSE_LOG4PHP_DIRECTORY', $palooseOptions[ 'LOG4PHP_DIR' ]  );
   define( 'PALOOSE_CACHE_DIR', $palooseOptions[ 'CACHE_DIR' ]  );
   define( 'PALOOSE_ROOT_SITEMAP', $palooseOptions[ 'ROOT_SITEMAP' ]  );
   define( 'PALOOSE_USER_EXCEPTION_PAGE', $palooseOptions[ 'USER_EXCEPTION_PAGE' ]  );
   define( 'PALOOSE_USER_EXCEPTION_TRANSFORM', $palooseOptions[ 'USER_EXCEPTION_TRANSFORM' ]  );
   define( 'PALOOSE_USER_EXCEPTION_STYLE', $palooseOptions[ 'USER_EXCEPTION_STYLE' ]  );
   define( 'PALOOSE_INTERNAL_EXCEPTION_PAGE', $palooseOptions[ 'INTERNAL_EXCEPTION_PAGE' ]  );
   define( 'PALOOSE_INTERNAL_EXCEPTION_TRANSFORM', $palooseOptions[ 'INTERNAL_EXCEPTION_TRANSFORM' ]  );
   define( 'PALOOSE_INTERNAL_EXCEPTION_STYLE', $palooseOptions[ 'INTERNAL_EXCEPTION_STYLE' ]  );

   // The following are always fixed
   define( 'PALOOSE_SITEMAP_NAMESPACE', 'http://apache.org/cocoon/sitemap/1.0' );
   define( 'PALOOSE_SOURCE_NAMESPACE', 'http://apache.org/cocoon/source/1.0' );
   define( 'PALOOSE_DIR_NAMESPACE', 'http://apache.org/cocoon/directory/2.0' );
   define( 'PALOOSE_SQL_QUERY_NAMESPACE', 'http://apache.org/cocoon/SQL/2.0' );
   define( 'PALOOSE_I18N_NAMESPACE', 'http://apache.org/cocoon/i18n/2.1' );
   define( 'PALOOSE_PAGE_HIT_TRANSFORM', 'resource://resources/transforms/PageHit.xsl' );
   define( 'PALOOSE_NAMESPACE', 'http://www.paloose.org/schemas/Paloose/1.0' );

   // These last two are very important and tell Paloose that it is working as a client
   // to WordPress rather than as a server in its own right. There is no opportunity to reset
   // these on the options page (obviously).
   define( 'PALOOSE_CLIENT', 'yes' );
   define( 'PALOOSE_SESSIONS_REQUIRED', 'no' );
   
   ini_set( 'track_errors', '1' );
   require_once( PALOOSE_DIRECTORY . '/lib/Paloose.php' );
   $paloose = new Paloose();
   
   $paloose->run( $inPage, $inQueryString );
   $palooseReturnString = Environment::$gClientBuffer;
   unset( $paloose );
   return $palooseReturnString;

} // paloose

?>