<?php

// -*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
// -*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
/**
 * LICENSE:
 * 
 * Paloose is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program.  If not, see <http://www.gnu.org/licenses/> 
 *
 * @package paloose
 * @subpackage environment
 * @author Hugh Field-Richards <hsfr@hsfr.org.uk>
 * @version See {@link Paloose.php}
 * @license http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @copyright 2006 - 2011 Hugh Field-Richards
 */

//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
/**
 */
 
require_once( PALOOSE_LIB_DIRECTORY . "/environment/Utilities.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/environment/Environment.php" );
require_once( PALOOSE_LIB_DIRECTORY . "/sitemap/VariableStack.php" );

//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
/**
 * The <i>StringResolver</i> Class expands pseudo-protocols and
 * sitemap variables.
 *
 * Parts are based on the Cocoon Java equivalent.
 *
 * @package paloose
 * @subpackage environment
 */
 
class StringResolver {

   //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
   //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
   /**
    * Expands a string with a previously analysed regexp. It caters for previous
    * context constructions such as "{../../1}".
    *
    * @param array $inVariableStack stack containing the arrays of the various regexp expansions.
    * @param string $inData the string to expand.
    * @return string after parameter substitution.
    */

   public static function expandString( $inVariableStack, $inData )
   {
      // First resolve all the variables (not the matcher variables from the reg expressions).
      // This must be done first. The form of these variables is {module:variable}
      //echo "<br/>------<br/>";
      //echo "[inData: $inData]<br/>";
      $outputData = $inData;
      $finished = false;
      $idx = 0;
      while ( !$finished ) {
         // Always start looking at the start of the string
         $lcbPos = strpos( $outputData, '{' );
         $rcbPos = strpos( $outputData, '}' );
         //echo "[lcbPos: $lcbPos][rcbPos: $rcbPos][$outputData]<br/>";
         if ( $lcbPos === false ) {
            $finished = true;
         } else {
            // Possible variable found, it can be either {n} or {module:variable}
            $var = substr( $outputData, $lcbPos+1, $rcbPos-$lcbPos-1 );
            $pair = explode( ":", $var );
            if ( $pair != NULL and sizeof( $pair ) == 2 ) {
               // There is something to process
               $module = Environment::$modules[ $pair[0] ];
               //echo "[module:{$pair[0]}:{$pair[1]}]<br/>";
               $replacementString = $module->get( $pair[1] );
               //echo "[{$pair[0]}:{$pair[1]}][{$replacementString}]<br/>";
               $srcString = substr( $outputData, $lcbPos, $rcbPos - $lcbPos + 1 );
               //echo "[src string: '$srcString'][replacement string: '$replacementString']<br/>";
               if ( is_string( $replacementString ) ) {
                  $outputData = str_replace( $srcString, $replacementString, $outputData );
               } else {
                  $outputData = $replacementString;
                  return $outputData;
               }
               //echo "[result string: '$outputData']<br/>";
            } else {
               // It is a straight {n} sitemap variable
               $var = substr( $outputData, $lcbPos+1, $rcbPos-$lcbPos-1 );
               //echo "[var: $var]<br/>";
               $replacementString = self::processVar( $inVariableStack, $var );
               $srcString = substr( $outputData, $lcbPos, $rcbPos - $lcbPos + 1 );
               //echo "[src string: '$srcString'][rep string: '$replacementString'][result string: '$outputData']<br/>";
               $outputData = str_replace( $srcString, $replacementString, $outputData );
               //echo "[src string: '$srcString'][rep string: '$replacementString'][result string: '$outputData']<br/>";
            }
            $idx += $rcbPos;
            if ( $idx >= strlen( $outputData ) ) {
               $finished = true;
            }
         }
      }

      //echo "[Expanded data: '$outputData']<br/>";
      return $outputData;
   }

   //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
   //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
   /**
    * Process the variable string. This analyses strings of the form "../../n" and
    * returns the appropriate string resolved from the variable stack level (2 in
    * the above form), and entry position (n) on the variable list.
    *
    * @param array $inVariableStack stack containing the arrays of the various regexp expansions.
    * @param string $inVar the variable string to resolve.
    * @return string the resolved string.
    */

   private static function processVar( $inVariableStack, $inVar )
   { 
      $p = explode( "/", $inVar );
      //echo "[var: " . $inVar . "]<br/>";
      $level = sizeof( $p ) - 1;
      //echo "[level: " . $level . "]<br/>";
      $map = $inVariableStack->entryAt( $level );
      $varIndex = $p[ sizeof( $p ) - 1 ];
      //echo "[varIndex: $varIndex]<br/>";
      //echo "[map entry: " . $map[ $varIndex ] . "]<br/>";
      if ( array_key_exists( $varIndex, $map ) ) {
         return $map[ $varIndex ];
      }
      return "";
   } 
   
   //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
   //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
   /**
    * Expand the pseudo protocols. For example "context://".
    *
    * @param string $inString the string to be expanded
    * @return string the expanded string
    */

   public static function expandPseudoProtocols( $inString )
   {
      if ( !is_string( $inString ) ) {
         return $inString;
      }
      $orig = $inString;
      $srcString = "resource://";
      if ( strpos( $inString, $srcString ) !== false ) {
         return str_replace( $srcString, PALOOSE_DIRECTORY . Environment::getPathSeparator(), $inString );
      }
      $srcString = "context://";
      if ( strpos( $inString, $srcString ) !== false ) {
         return str_replace( $srcString, Environment::$configuration[ 'siteRootDirectory' ] . Environment::getPathSeparator(), $inString );
      }
      $srcString = "cocoon://";
      if ( strpos( $inString, $srcString ) !== false ) {
         return str_replace( $srcString, Environment::$gRootSitemapDir . Environment::getPathSeparator(), $inString );
      }
      $srcString = "cocoon:/";
      if ( strpos( $inString, $srcString ) !== false ) {
         return str_replace( $srcString, Environment::$gCurrentSitemapDir . Environment::getPathSeparator(), $inString );
      }
      return $inString;
   }

  //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
   /**
    * Remove the pseudo protocols. This is a special case of the above where we
    * never have relative directories. In other words we eat "cocoon://" etc.,
    * but not "context://" or "resource://" which we expand. Nasty but necessary.
    *
    * @param string $inString the string to be altered
    * @return string the altered string
    */

   public function removePseudoProtocols( $inString )
   {
      $srcString = "resource://";
      if ( strpos( $inString, $srcString ) !== false ) {
         return str_replace( $srcString, PALOOSE_DIRECTORY . Environment::getPathSeparator(), $inString );
      }
      $srcString = "context://";
      if ( strpos( $inString, $srcString ) !== false ) {
         return str_replace( $srcString, Environment::getContext(), $inString );
      }
      $srcString = "cocoon://";
      if ( strpos( $inString, $srcString ) !== false ) {
         return str_replace( $srcString, "", $inString );
      }
      $srcString = "cocoon:/";
      if ( strpos( $inString, $srcString ) !== false ) {
         return str_replace( $srcString, "", $inString );
      }
      return $inString;
   }

}

?>